Installation
############

Pip
===

.. code-block:: bash

   pip install tcrdist-rs 


Conda
=====

There is no Conda installation presently.

.. todo::
   Publish Conda package

Developer
=========

See :doc:`developer`.
